@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2009 Michael Howitz
+# Copyright (c) 2009-2011 Michael Howitz
 # See also LICENSE.txt
 
 from icemac.addressbook.i18n import MessageFactory as _
 import icemac.ab.importer.browser.wizard.base
 import icemac.addressbook.browser.file.file
+import icemac.addressbook.browser.wizard
 import icemac.addressbook.file.interfaces
 
 
-class EditFile(icemac.ab.importer.browser.wizard.base.Step):
+class EditFile(icemac.addressbook.browser.wizard.Step):
 
     interface = icemac.addressbook.file.interfaces.IFile
     label = _(u'Edit import file')
